You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by ta...@apache.org on 2009/05/21 12:26:17 UTC

svn commit: r777039 [1/15] - in /activemq/activemq-cpp/trunk/activemq-cpp/src/main: activemq/cmsutil/ activemq/commands/ activemq/exceptions/ activemq/io/ activemq/transport/ activemq/transport/failover/ activemq/transport/mock/ activemq/transport/tcp/...

Author: tabish
Date: Thu May 21 10:26:09 2009
New Revision: 777039

URL: http://svn.apache.org/viewvc?rev=777039&view=rev
Log:
Fix many doxygen warnings and clean up the code documentation for the next release.

Modified:
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/cmsutil/CmsTemplate.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQBytesMessage.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQDestination.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQMapMessage.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQMessageTemplate.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQStreamMessage.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/WireFormatInfo.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/exceptions/ActiveMQException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/io/LoggingInputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/io/LoggingOutputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/CompositeTransport.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/IOTransport.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/Transport.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/TransportFilter.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/TransportListener.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/failover/BackupTransport.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/failover/FailoverTransport.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/mock/MockTransport.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/mock/MockTransportFactory.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/tcp/TcpTransport.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/tcp/TcpTransportFactory.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/PrimitiveMap.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/PrimitiveValueNode.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/URISupport.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/WireFormat.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/OpenWireFormat.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/OpenWireFormatNegotiator.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/BaseDataStreamMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/PrimitiveTypesMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQBlobMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQBytesMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQDestinationMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQMapMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQObjectMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQQueueMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQStreamMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQTempDestinationMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQTempQueueMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQTempTopicMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQTextMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ActiveMQTopicMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/BaseCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/BrokerIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/BrokerInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ConnectionControlMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ConnectionErrorMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ConnectionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ConnectionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ConsumerControlMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ConsumerIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ConsumerInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ControlCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/DataArrayResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/DataResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/DestinationInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/DiscoveryEventMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ExceptionResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/FlushCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/IntegerResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/JournalQueueAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/JournalTopicAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/JournalTraceMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/JournalTransactionMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/KeepAliveInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/LastPartialCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/LocalTransactionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/MessageAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/MessageDispatchMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/MessageDispatchNotificationMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/MessageIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/MessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/MessagePullMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/NetworkBridgeFilterMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/PartialCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ProducerAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ProducerIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ProducerInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/RemoveInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/RemoveSubscriptionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ReplayCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/SessionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/SessionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/ShutdownInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/SubscriptionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/TransactionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/TransactionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/WireFormatInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v1/XATransactionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQBlobMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQBytesMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQDestinationMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQMapMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQObjectMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQQueueMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQStreamMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQTempDestinationMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQTempQueueMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQTempTopicMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQTextMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ActiveMQTopicMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/BaseCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/BrokerIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/BrokerInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ConnectionControlMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ConnectionErrorMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ConnectionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ConnectionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ConsumerControlMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ConsumerIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ConsumerInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ControlCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/DataArrayResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/DataResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/DestinationInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/DiscoveryEventMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ExceptionResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/FlushCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/IntegerResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/JournalQueueAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/JournalTopicAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/JournalTraceMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/JournalTransactionMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/KeepAliveInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/LastPartialCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/LocalTransactionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/MessageAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/MessageDispatchMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/MessageDispatchNotificationMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/MessageIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/MessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/MessagePullMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/NetworkBridgeFilterMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/PartialCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ProducerAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ProducerIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ProducerInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/RemoveInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/RemoveSubscriptionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ReplayCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/SessionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/SessionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/ShutdownInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/SubscriptionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/TransactionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/TransactionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/WireFormatInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v2/XATransactionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQBlobMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQBytesMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQDestinationMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQMapMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQObjectMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQQueueMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQStreamMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQTempDestinationMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQTempQueueMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQTempTopicMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQTextMessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ActiveMQTopicMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/BaseCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/BrokerIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/BrokerInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ConnectionControlMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ConnectionErrorMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ConnectionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ConnectionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ConsumerControlMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ConsumerIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ConsumerInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ControlCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/DataArrayResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/DataResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/DestinationInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/DiscoveryEventMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ExceptionResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/FlushCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/IntegerResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/JournalQueueAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/JournalTopicAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/JournalTraceMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/JournalTransactionMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/KeepAliveInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/LastPartialCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/LocalTransactionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/MessageAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/MessageDispatchMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/MessageDispatchNotificationMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/MessageIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/MessageMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/MessagePullMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/NetworkBridgeFilterMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/PartialCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ProducerAckMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ProducerIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ProducerInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/RemoveInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/RemoveSubscriptionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ReplayCommandMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ResponseMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/SessionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/SessionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/ShutdownInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/SubscriptionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/TransactionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/TransactionInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/WireFormatInfoMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/marshal/v3/XATransactionIdMarshaller.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/utils/HexTable.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/stomp/StompHelper.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/stomp/StompWireFormat.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/io/StandardErrorOutputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/io/StandardInputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/io/StandardOutputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/net/URIHelper.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/net/URIType.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/nio/ByteArrayBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/nio/CharArrayBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/nio/DoubleArrayBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/nio/FloatArrayBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/nio/IntArrayBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/nio/LongArrayBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/internal/nio/ShortArrayBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/BlockingByteArrayInputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/BufferedInputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/BufferedOutputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/ByteArrayInputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/ByteArrayOutputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/DataInputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/EOFException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/FilterInputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/FilterOutputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/IOException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/InterruptedIOException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/OutputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/Reader.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/UTFDataFormatException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/io/Writer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/BindException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/ConnectException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/HttpRetryException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/MalformedURLException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/NoRouteToHostException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/PortUnreachableException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/ProtocolException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/SocketException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/SocketFactory.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/SocketInputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/SocketOutputStream.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/SocketTimeoutException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/TcpSocket.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/URISyntaxException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/URLDecoder.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/URLEncoder.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/UnknownHostException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/net/UnknownServiceException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/BufferOverflowException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/BufferUnderflowException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ByteBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/CharBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/DoubleBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/FloatBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/IntBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/InvalidMarkException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/LongBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ReadOnlyBufferException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ShortBuffer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/GeneralSecurityException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/InvalidKeyException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/Key.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/KeyException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/NoSuchAlgorithmException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/NoSuchProviderException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/Principal.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/PublicKey.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/SignatureException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/Certificate.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateEncodingException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateExpiredException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateNotYetValidException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateParsingException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/X509Certificate.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/AbstractCollection.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Comparator.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/List.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Map.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Properties.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Random.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Set.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/StlMap.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/StringTokenizer.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/BrokenBarrierException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/CancellationException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/Concurrent.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/ConcurrentStlMap.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/ExecutionException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/PooledThreadListener.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/RejectedExecutionException.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/locks/Condition.h
    activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/locks/ReadWriteLock.h

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/cmsutil/CmsTemplate.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/cmsutil/CmsTemplate.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/cmsutil/CmsTemplate.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/cmsutil/CmsTemplate.h Thu May 21 10:26:09 2009
@@ -511,11 +511,12 @@
          * Executes the given action and provides it with a CMS Session and
          * producer
          *
-         * @param dest
+         * @param destinationName
          *          the name of the destination to send messages to
          *          (to internally be resolved to an actual destination)
          * @param action
          *          the action to perform
+         *
          * @throws cms::CMSException thrown if an error occurs.
          */
         virtual void execute( const std::string& destinationName,

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQBytesMessage.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQBytesMessage.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQBytesMessage.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQBytesMessage.h Thu May 21 10:26:09 2009
@@ -99,6 +99,10 @@
          * Compares the DataStructure passed in to this one, and returns if
          * they are equivalent.  Equivalent here means that they are of the
          * same type, and that each element of the objects are the same.
+         *
+         * @param value
+         *      The Command to compare to this one.
+         *
          * @returns true if DataStructure's are Equal.
          */
         virtual bool equals( const DataStructure* value ) const;
@@ -130,8 +134,11 @@
 
         /**
          * sets the bytes given to the message body.
-         * @param Byte Buffer to copy
-         * @param Number of bytes in Buffer to copy
+         *
+         * @param buffer
+         *      Byte Buffer to copy.
+         * @param numBytes
+         *      Number of bytes in Buffer to copy.
          * @throws CMSException
          */
         virtual void setBodyBytes( const unsigned char* buffer,
@@ -214,7 +221,7 @@
         /**
          * Writes a byte array to the bytes message stream using the vector
          * size as the number of bytes to write.
-         * @param value - bytes to write to the stream
+         * @param value - bytes to write to the stream.
          * @throws CMSException
          */
         virtual void writeBytes(
@@ -237,7 +244,7 @@
          * array value, then an IndexOutOfBoundsException is thrown. No bytes
          * will be read from the stream for this exception case.
          *
-         * @param value - the buffer into which the data is read
+         * @param buffer - the buffer into which the data is read
          * @param length - the number of bytes to read; must be less than or
          *                 equal to value.length
          * @returns the total number of bytes read into the buffer, or -1 if

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQDestination.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQDestination.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQDestination.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQDestination.h Thu May 21 10:26:09 2009
@@ -299,10 +299,7 @@
          * Returns true if this destination represents a collection of
          * destinations; allowing a set of destinations to be published to or
          * subscribed from in one CMS operation.
-         * <p/>
-         * If this destination is a composite then you can call
-         * {@link #getChildDestinations()}
-         * to return the list of child destinations.
+         *
          * @return true if this destination represents a collection of child
          *         destinations.
          */
@@ -319,7 +316,7 @@
         }
 
         /**
-         * @returns a reference (const) to the options properties for this Dest.
+         * @returns a reference (const) to the options properties for this Destination.
          */
         const activemq::util::ActiveMQProperties& getOptions() const {
             return options;

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQMapMessage.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQMapMessage.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQMapMessage.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQMapMessage.h Thu May 21 10:26:09 2009
@@ -79,7 +79,7 @@
 
         /**
          * Perform any processing needed before an marshal
-         * @param wireformat - the OpenWireFormat object in use.
+         * @param wireFormat - the OpenWireFormat object in use.
          */
         virtual void beforeMarshal( wireformat::WireFormat* wireFormat )
             throw ( decaf::io::IOException );

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQMessageTemplate.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQMessageTemplate.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQMessageTemplate.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQMessageTemplate.h Thu May 21 10:26:09 2009
@@ -352,6 +352,7 @@
         /**
          * Get the Correlation Id for this message
          * @return string representation of the correlation Id
+         * @throw CMSException
          */
         virtual std::string getCMSCorrelationID() const throw( cms::CMSException ) {
             return this->getCorrelationId();
@@ -360,6 +361,7 @@
         /**
          * Sets the Correlation Id used by this message
          * @param correlationId - String representing the correlation id.
+         * @throw CMSException
          */
         virtual void setCMSCorrelationID( const std::string& correlationId ) throw( cms::CMSException ) {
             this->setCorrelationId( correlationId );
@@ -368,6 +370,7 @@
         /**
          * Gets the DeliveryMode for this message
          * @return DeliveryMode enumerated value.
+         * @throw CMSException
          */
         virtual int getCMSDeliveryMode() const throw( cms::CMSException ) {
             return this->isPersistent();
@@ -376,6 +379,7 @@
         /**
          * Sets the DeliveryMode for this message
          * @param mode - DeliveryMode enumerated value.
+         * @throw CMSException
          */
         virtual void setCMSDeliveryMode( int mode ) throw( cms::CMSException ) {
             this->setPersistent( mode == (int)cms::DeliveryMode::PERSISTENT );
@@ -384,6 +388,7 @@
         /**
          * Gets the Destination for this Message, returns a
          * @return Destination object
+         * @throw CMSException
          */
         virtual const cms::Destination* getCMSDestination() const throw( cms::CMSException ) {
             return dynamic_cast<const cms::Destination*>( this->getDestination().get() );
@@ -392,6 +397,7 @@
         /**
          * Sets the Destination for this message
          * @param destination - Destination Object
+         * @throw CMSException
          */
         virtual void setCMSDestination( const cms::Destination* destination )
             throw( cms::CMSException ) {
@@ -408,6 +414,7 @@
         /**
          * Gets the Expiration Time for this Message
          * @return time value
+         * @throw CMSException
          */
         virtual long long getCMSExpiration() const throw( cms::CMSException ) {
             return this->getExpiration();
@@ -416,6 +423,7 @@
         /**
          * Sets the Expiration Time for this message
          * @param expireTime - time value
+         * @throw CMSException
          */
         virtual void setCMSExpiration( long long expireTime ) throw( cms::CMSException ) {
             this->setExpiration( expireTime );
@@ -424,6 +432,7 @@
         /**
          * Gets the CMS Message Id for this Message
          * @return time value
+         * @throw CMSException
          */
         virtual std::string getCMSMessageID() const throw( cms::CMSException ) {
             return wireformat::openwire::marshal::BaseDataStreamMarshaller::toString( this->getMessageId().get() );
@@ -432,12 +441,16 @@
         /**
          * Sets the CMS Message Id for this message
          * @param id - time value
+         * @throw CMSException
          */
-        virtual void setCMSMessageID( const std::string& id AMQCPP_UNUSED ) throw( cms::CMSException )  {}
+        virtual void setCMSMessageID( const std::string& id AMQCPP_UNUSED )
+            throw( cms::CMSException ) {
+        }
 
         /**
          * Gets the Priority Value for this Message
          * @return priority value
+         * @throw CMSException
          */
         virtual int getCMSPriority() const throw( cms::CMSException ) {
             return this->getPriority();
@@ -446,6 +459,7 @@
         /**
          * Sets the Priority Value for this message
          * @param priority - priority value for this message
+         * @throw CMSException
          */
         virtual void setCMSPriority( int priority ) throw( cms::CMSException ) {
             this->setPriority( priority );
@@ -454,6 +468,7 @@
         /**
          * Gets the Redelivered Flag for this Message
          * @return redelivered value
+         * @throw CMSException
          */
         virtual bool getCMSRedelivered() const throw( cms::CMSException ) {
             return this->getRedeliveryCounter() != 0;
@@ -462,12 +477,14 @@
         /**
          * Sets the Redelivered Flag for this message
          * @param redelivered - boolean redelivered value
+         * @throw CMSException
          */
         virtual void setCMSRedelivered( bool redelivered AMQCPP_UNUSED ) throw( cms::CMSException )  {}
 
         /**
          * Gets the CMS Reply To Address for this Message
          * @return Reply To Value
+         * @throw CMSException
          */
         virtual const cms::Destination* getCMSReplyTo() const throw( cms::CMSException ) {
             return dynamic_cast< const cms::Destination* >(
@@ -476,7 +493,11 @@
 
         /**
          * Sets the CMS Reply To Address for this message
-         * @param id - Reply To value
+         *
+         * @param destination
+         *      Pointer to the CMS Destination that is the Reply-To value.
+         *
+         * @throw CMSException
          */
         virtual void setCMSReplyTo( const cms::Destination* destination ) throw( cms::CMSException ) {
 
@@ -492,6 +513,7 @@
         /**
          * Gets the Time Stamp for this Message
          * @return time stamp value
+         * @throw CMSException
          */
         virtual long long getCMSTimestamp() const throw( cms::CMSException ) {
             return this->getTimestamp();
@@ -500,6 +522,7 @@
         /**
          * Sets the Time Stamp for this message
          * @param timeStamp - integer time stamp value
+         * @throw CMSException
          */
         virtual void setCMSTimestamp( long long timeStamp ) throw( cms::CMSException ) {
             this->setTimestamp( timeStamp );
@@ -508,6 +531,7 @@
         /**
          * Gets the CMS Message Type for this Message
          * @return type value
+         * @throw CMSException
          */
         virtual std::string getCMSType() const throw( cms::CMSException ) {
             return this->getType();
@@ -516,6 +540,7 @@
         /**
          * Sets the CMS Message Type for this message
          * @param type - message type value string
+         * @throw CMSException
          */
         virtual void setCMSType( const std::string& type ) throw( cms::CMSException ) {
             this->setType( type );

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQStreamMessage.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQStreamMessage.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQStreamMessage.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/ActiveMQStreamMessage.h Thu May 21 10:26:09 2009
@@ -101,7 +101,7 @@
 
         /**
          * Perform any processing needed before an marshal
-         * @param wireformat - the OpenWireFormat object in use.
+         * @param wireFormat - the OpenWireFormat object in use.
          */
         virtual void beforeMarshal( wireformat::WireFormat* wireFormat )
             throw ( decaf::io::IOException );
@@ -214,7 +214,7 @@
          * array value, then an IndexOutOfBoundsException is thrown. No bytes
          * will be read from the stream for this exception case.
          *
-         * @param value - the buffer into which the data is read
+         * @param buffer - the buffer into which the data is read
          * @param length - the number of bytes to read; must be less than or
          *                 equal to value.length
          * @returns the total number of bytes read into the buffer, or -1 if

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/WireFormatInfo.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/WireFormatInfo.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/WireFormatInfo.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/commands/WireFormatInfo.h Thu May 21 10:26:09 2009
@@ -247,7 +247,9 @@
 
         /**
          * Sets the value of the marshalledProperties field
-         * @param magic - const std::vector<char>
+         * @param marshalledProperties
+         *      The Byte Array vector that contains the marshaled form of the Message
+         *      properties, this is the data sent over the wire.
          */
         void setMarshalledProperties( const std::vector<unsigned char>& marshalledProperties ) {
             this->marshalledProperties = marshalledProperties;
@@ -260,6 +262,11 @@
         virtual const util::PrimitiveMap& getProperties() const {
             return properties;
         }
+
+        /**
+         * Gets the Properties for this Command
+         * @return the Properties object for this Command.
+         */
         virtual util::PrimitiveMap& getProperties() {
             return properties;
         }

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/exceptions/ActiveMQException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/exceptions/ActiveMQException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/exceptions/ActiveMQException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/exceptions/ActiveMQException.h Thu May 21 10:26:09 2009
@@ -44,22 +44,33 @@
 
         /**
          * Copy Constructor
+         *
+         * @param ex
+         *      The Exception whose internal data is copied into this instance.
          */
         ActiveMQException( const ActiveMQException& ex ) throw();
 
         /**
          * Copy Constructor
+         *
+         * @param ex
+         *      The Exception whose internal data is copied into this instance.
          */
         ActiveMQException( const decaf::lang::Exception& ex ) throw();
 
         /**
          * Constructor - Initializes the file name and line number where
-         * this message occured.  Sets the message to report, using an
-         * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * this message occurred.  Sets the message to report, using an
+         * optional list of arguments to parse into the message.
+         *
+         * @param file
+         *      The file name where exception occurs.
+         * @param lineNumber
+         *      The line number where the exception occurred.
+         * @param msg
+         *      The message to report.
+         * @param ...
+         *      The list of primitives that are formatted into the message.
          */
         ActiveMQException( const char* file, const int lineNumber,
                            const char* msg, ... ) throw();
@@ -70,12 +81,14 @@
          * Clones this exception.  This is useful for cases where you need
          * to preserve the type of the original exception as well as the message.
          * All subclasses should override.
+         *
          * @return Copy of this Exception object
          */
         virtual ActiveMQException* clone() const;
 
         /**
          * Converts this exception to a new CMSException
+         *
          * @return a CMSException with the data from this exception
          */
         virtual cms::CMSException convertToCMSException() const;

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/io/LoggingInputStream.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/io/LoggingInputStream.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/io/LoggingInputStream.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/io/LoggingInputStream.h Thu May 21 10:26:09 2009
@@ -37,7 +37,7 @@
          * Creates a DataInputStream that uses the specified underlying
          * InputStream.
          * @param inputStream the InputStream instance to wrap.
-         * @param own, indicates if this class owns the wrapped string
+         * @param own indicates if this class owns the wrapped string
          * defaults to false.
          */
         LoggingInputStream( decaf::io::InputStream* inputStream, bool own = false );

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/io/LoggingOutputStream.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/io/LoggingOutputStream.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/io/LoggingOutputStream.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/io/LoggingOutputStream.h Thu May 21 10:26:09 2009
@@ -38,9 +38,12 @@
 
         /**
          * Constructor.
-         * @param outputStream the OutputStream to wrap
-         * @param own If true, this object will control the lifetime of the
-         * output stream that it encapsulates.
+         *
+         * @param next
+         *      The OutputStream to wrap an write logs to.
+         * @param own
+         *      If true, this object will control the lifetime of the
+         *      output stream that it encapsulates.
          */
         LoggingOutputStream( OutputStream* next, bool own = false );
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/CompositeTransport.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/CompositeTransport.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/CompositeTransport.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/CompositeTransport.h Thu May 21 10:26:09 2009
@@ -46,8 +46,8 @@
          * Add a URI to the list of URI's that will represent the set of Transports
          * that this Transport is a composite of.
          *
-         * @param uri
-         *        The new URI to add to the set this composite maintains.
+         * @param uris
+         *        The new URI set to add to the set this composite maintains.
          */
         virtual void addURI( const List<URI>& uris ) = 0;
 
@@ -57,8 +57,8 @@
          * has created a connected Transport should result in that Transport being
          * disposed of.
          *
-         * @param uri
-         *        The new URI to remove to the set this composite maintains.
+         * @param uris
+         *        The new URI set to remove to the set this composite maintains.
          */
         virtual void removeURI( const List<URI>& uris ) = 0;
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/IOTransport.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/IOTransport.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/IOTransport.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/IOTransport.h Thu May 21 10:26:09 2009
@@ -153,7 +153,9 @@
 
         /**
          * Sets the WireFormat instance to use.
-         * @param WireFormat the object used to encode / decode commands.
+         *
+         * @param wireFormat
+         *      The WireFormat the object used to encode / decode commands.
          */
         virtual void setWireFormat( const Pointer<wireformat::WireFormat>& wireFormat ){
             this->wireFormat = wireFormat;

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/Transport.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/Transport.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/Transport.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/Transport.h Thu May 21 10:26:09 2009
@@ -96,13 +96,14 @@
          * @throws UnsupportedOperationException if this method is not implemented
          * by this transport.
          */
-        virtual Pointer<Response> request( const Pointer<Command>&, unsigned int timeout )
+        virtual Pointer<Response> request( const Pointer<Command>& command, unsigned int timeout )
             throw( decaf::io::IOException,
                    decaf::lang::exceptions::UnsupportedOperationException ) = 0;
 
         /**
          * Sets the WireFormat instance to use.
-         * @param WireFormat the object used to encode / decode commands.
+         * @param wireFormat
+         *      The WireFormat the object used to encode / decode commands.
          */
         virtual void setWireFormat( const Pointer<wireformat::WireFormat>& wireFormat ) = 0;
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/TransportFilter.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/TransportFilter.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/TransportFilter.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/TransportFilter.h Thu May 21 10:26:09 2009
@@ -84,7 +84,6 @@
         /**
          * Constructor.
          * @param next - the next Transport in the chain
-         * @param own - true if this filter owns the next and should delete it
          */
         TransportFilter( const Pointer<Transport>& next );
 
@@ -100,8 +99,8 @@
 
         /**
          * Event handler for an exception from a command transport.
-         * @param source The source of the exception
-         * @param ex The exception.
+         * @param ex
+         *      The exception to handle.
          */
         virtual void onException( const decaf::lang::Exception& ex );
 
@@ -173,7 +172,8 @@
 
         /**
          * Sets the WireFormat instance to use.
-         * @param WireFormat the object used to encode / decode commands.
+         * @param wireFormat
+         *      The WireFormat the object used to encode / decode commands.
          */
         virtual void setWireFormat( const Pointer<wireformat::WireFormat>& wireFormat ) {
             next->setWireFormat( wireFormat );

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/TransportListener.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/TransportListener.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/TransportListener.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/TransportListener.h Thu May 21 10:26:09 2009
@@ -53,8 +53,8 @@
         /**
          * Event handler for an exception from a command transport.
          *
-         * @param source The source of the exception
-         * @param ex The exception.
+         * @param ex
+         *      The exception being propagated to this listener to handle.
          */
         virtual void onException( const decaf::lang::Exception& ex ) = 0;
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/failover/BackupTransport.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/failover/BackupTransport.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/failover/BackupTransport.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/failover/BackupTransport.h Thu May 21 10:26:09 2009
@@ -95,8 +95,12 @@
 
         /**
          * Event handler for an exception from a command transport.
-         * @param source The source of the exception
-         * @param ex The exception.
+         * <p>
+         * The BackupTransport closes its internal Transport when an exception is
+         * received and returns the URI to the pool of URIs to attempt connections to.
+         *
+         * @param ex
+         *      The exception that was passed to this listener to handle.
          */
         virtual void onException( const decaf::lang::Exception& ex );
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/failover/FailoverTransport.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/failover/FailoverTransport.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/failover/FailoverTransport.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/failover/FailoverTransport.h Thu May 21 10:26:09 2009
@@ -193,7 +193,8 @@
 
         /**
          * Sets the WireFormat instance to use.
-         * @param WireFormat the object used to encode / decode commands.
+         * @param wireFormat
+         *      The WireFormat the object used to encode / decode commands.
          */
         virtual void setWireFormat( const Pointer<wireformat::WireFormat>& wireFormat AMQCPP_UNUSED ) {}
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/mock/MockTransport.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/mock/MockTransport.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/mock/MockTransport.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/mock/MockTransport.h Thu May 21 10:26:09 2009
@@ -106,7 +106,7 @@
                    decaf::lang::exceptions::UnsupportedOperationException);
 
 
-        virtual Pointer<Response> request( const Pointer<Command>&, unsigned int timeout )
+        virtual Pointer<Response> request( const Pointer<Command>& command, unsigned int timeout )
             throw( decaf::io::IOException,
                    decaf::lang::exceptions::UnsupportedOperationException);
 
@@ -122,7 +122,9 @@
 
         /**
          * Sets the WireFormat instance to use.
-         * @param WireFormat the object used to encode / decode commands.
+         *
+         * @param wireFormat
+         *      WireFormat the object used to encode / decode commands.
          */
         virtual void setWireFormat( const Pointer<wireformat::WireFormat>& wireFormat AMQCPP_UNUSED ) {}
 
@@ -156,7 +158,9 @@
         /**
          * Fires a Exception back through this transport to its registered
          * ExceptionListener if there is one.
-         * @param command - Command to send to the Listener.
+         *
+         * @param ex
+         *      The Exception that will be passed on the the Transport listener.
          */
         virtual void fireException( const exceptions::ActiveMQException& ex ){
             if( listener != NULL ){

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/mock/MockTransportFactory.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/mock/MockTransportFactory.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/mock/MockTransportFactory.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/mock/MockTransportFactory.h Thu May 21 10:26:09 2009
@@ -61,7 +61,7 @@
          * transport instances.
          *
          * @param location - URI location to connect to.
-         * @param wireformat - the assigned WireFormat for the new Transport.
+         * @param wireFormat - the assigned WireFormat for the new Transport.
          * @param properties - Properties to apply to the transport.
          *
          * @return Pointer to a new Transport instance.

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/tcp/TcpTransport.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/tcp/TcpTransport.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/tcp/TcpTransport.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/tcp/TcpTransport.h Thu May 21 10:26:09 2009
@@ -73,7 +73,6 @@
          * Constructor
          * @param properties the configuration properties for this transport
          * @param next the next transport in the chain
-         * @param own indicates if this transport owns the next.
          */
         TcpTransport( const decaf::util::Properties& properties,
                       const Pointer<Transport>& next );
@@ -83,7 +82,6 @@
          * @param uri - The URI containing the host to connect to.
          * @param properties the configuration properties for this transport
          * @param next the next transport in the chain
-         * @param own indicates if this transport owns the next.
          */
         TcpTransport( const decaf::net::URI& uri,
                       const decaf::util::Properties& properties,

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/tcp/TcpTransportFactory.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/tcp/TcpTransportFactory.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/tcp/TcpTransportFactory.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/transport/tcp/TcpTransportFactory.h Thu May 21 10:26:09 2009
@@ -61,7 +61,7 @@
          * transport instances.
          *
          * @param location - URI location to connect to.
-         * @param wireformat - the assigned WireFormat for the new Transport.
+         * @param wireFormat - the assigned WireFormat for the new Transport.
          * @param properties - Properties to apply to the transport.
          *
          * @return new Pointer to a TcpTransport.

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/PrimitiveMap.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/PrimitiveMap.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/PrimitiveValueNode.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/PrimitiveValueNode.h Thu May 21 10:26:09 2009
@@ -171,20 +171,20 @@
 
         /**
          * Copy constructor
-         * @param another node to copy.
+         * @param node
+         *      The instance of another node to copy to this one.
          */
         PrimitiveValueNode( const PrimitiveValueNode& node );
 
-        /**
-         * Destructor, clears the data before destruction to free any data
-         * in the PrimitiveValue union.
-         */
         ~PrimitiveValueNode(){
             clear();
         }
 
         /**
          * Assignment operator, copies the data from the other node.
+         *
+         * @param node
+         *      The instance of another node to copy to this one.
          */
         PrimitiveValueNode& operator =( const PrimitiveValueNode& node );
 
@@ -211,6 +211,11 @@
         /**
          * Sets the internal PrimitiveVale object to the new value
          * along with the tag for the type that it consists of.
+         *
+         * @param value
+         *      The value to set as the value contained in this Node.
+         * @param valueType
+         *      The type of the value being set into this one.
          */
         void setValue( const PrimitiveValue& value, PrimitiveType valueType );
 
@@ -226,7 +231,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setBool( bool lvalue );
+        void setBool( bool value );
 
         /**
          * Gets the Boolean value of this Node.
@@ -243,7 +248,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setByte( unsigned char lvalue );
+        void setByte( unsigned char value );
 
         /**
          * Gets the Byte value of this Node.
@@ -260,7 +265,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setChar( char lvalue );
+        void setChar( char value );
 
         /**
          * Gets the Character value of this Node.
@@ -277,7 +282,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setShort( short lvalue );
+        void setShort( short value );
 
         /**
          * Gets the Short value of this Node.
@@ -294,7 +299,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setInt( int lvalue );
+        void setInt( int value );
 
         /**
          * Gets the Integer value of this Node.
@@ -311,7 +316,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setLong( long long lvalue );
+        void setLong( long long value );
 
         /**
          * Gets the Long value of this Node.
@@ -328,7 +333,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setFloat( float lvalue );
+        void setFloat( float value );
 
         /**
          * Gets the Float value of this Node.
@@ -345,7 +350,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setDouble( double lvalue );
+        void setDouble( double value );
 
         /**
          * Gets the Double value of this Node.
@@ -362,7 +367,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setString( const std::string& lvalue );
+        void setString( const std::string& value );
 
         /**
          * Gets the String value of this Node.
@@ -379,7 +384,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setByteArray( const std::vector<unsigned char>& lvalue );
+        void setByteArray( const std::vector<unsigned char>& value );
 
         /**
          * Gets the Byte Array value of this Node.
@@ -396,7 +401,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setList( const decaf::util::List<PrimitiveValueNode>& lvalue );
+        void setList( const decaf::util::List<PrimitiveValueNode>& value );
 
         /**
          * Gets the Primitive List value of this Node.
@@ -413,7 +418,7 @@
          * given.
          * @param value - the new value to assign to the element at index
          */
-        void setMap( const decaf::util::Map<std::string, PrimitiveValueNode>& lvalue );
+        void setMap( const decaf::util::Map<std::string, PrimitiveValueNode>& value );
 
         /**
          * Gets the Primitive Map value of this Node.

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/URISupport.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/URISupport.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/URISupport.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/URISupport.h Thu May 21 10:26:09 2009
@@ -58,7 +58,10 @@
          * Parse the Query portion of a URI String and return a Simple
          * Properties object containing the parameter names as keys, and
          * the parameter values and values of the Properties.
-         * @param query. the query string to parse.
+         *
+         * @param query
+         *      The query string to parse and extract the encoded properties.
+         *
          * @returns Properties object with the parsed output.
          *
          * @throw IllegalArgumentException if the Query string is not well formed.

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/WireFormat.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/WireFormat.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/WireFormat.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/WireFormat.h Thu May 21 10:26:09 2009
@@ -51,8 +51,13 @@
          * Stream based marshaling of a Command, this method blocks until the entire
          * Command has been written out to the output stream.
          *
-         * @param command - The Command to Marshal
-         * @param out - the output stream to write the command to.
+         * @param command
+         *      The Command to Marshal
+         * @param transport
+         *      The Transport that called this method.
+         * @param out
+         *      The output stream to write the command to.
+         *
          * @throws IOException
          */
         virtual void marshal( const Pointer<commands::Command>& command,
@@ -76,7 +81,9 @@
 
         /**
          * Set the Version
-         * @param the version of the wire format
+         *
+         * @param version
+         *      the version of the wire format
          */
         virtual void setVersion( int version ) = 0;
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/OpenWireFormat.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/OpenWireFormat.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/OpenWireFormatNegotiator.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/OpenWireFormatNegotiator.h Thu May 21 10:26:09 2009
@@ -69,7 +69,6 @@
          * Constructor - Initializes this object around another Transport
          * @param wireFormat - The WireFormat object we use to negotiate
          * @param next - The next transport in the chain
-         * @param own - do we own the Transport pointer.
          */
         OpenWireFormatNegotiator( OpenWireFormat* wireFormat,
                                   const Pointer<transport::Transport>& next );
@@ -80,7 +79,7 @@
          * Sends a one-way command.  Does not wait for any response from the
          * broker.
          * First waits for the WireFormatInfo exchange to happen so that we
-         * know how to encode outbound data.
+         * know how to encode out-bound data.
          * @param command the command to be sent.
          * @throws IOException if an exception occurs during writing of
          * the command.
@@ -94,7 +93,7 @@
         /**
          * Sends the given request to the server and waits for the response.
          * First waits for the WireFormatInfo exchange to happen so that we
-         * know how to encode outbound data.
+         * know how to encode out-bound data.
          * @param command The request to send.
          * @return the response from the server.
          * @throws IOException if an error occurs with the request.
@@ -106,7 +105,7 @@
         /**
          * Sends the given request to the server and waits for the response.
          * First waits for the WireFormatInfo exchange to happen so that we
-         * know how to encode outbound data.
+         * know how to encode out-bound data.
          * @param command The request to send.
          * @param timeout The time to wait for the response.
          * @return the response from the server.
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/PrimitiveMap.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/PrimitiveMap.h Thu May 21 10:26:09 2009
@@ -49,19 +49,24 @@
 
         /**
          * Copy Constructor
-         * @param map - the Decaf Map of PrimitiveValueNodes to copy
+         *
+         * @param source
+         *      The Decaf Library Map instance whose elements will be copied into this Map.
          */
-        PrimitiveMap( const decaf::util::Map<std::string, PrimitiveValueNode>& src );
+        PrimitiveMap( const decaf::util::Map<std::string, PrimitiveValueNode>& source );
 
         /**
          * Copy Constructor
          * @param map - the PrimitiveMap to copy
          */
-        PrimitiveMap( const PrimitiveMap& src );
+        PrimitiveMap( const PrimitiveMap& source );
 
         /**
          * Converts the contents into a formatted string that can be output
          * in a Log File or other debugging tool.
+         *
          * @returns formatted String of all elements in the map.
          */
         std::string toString() const;
@@ -49,19 +49,24 @@
         /**
          * Copy Constructor
-         * @param map - the PrimitiveMap to copy
+         *
+         * @param source
+         *      The PrimitiveMap whose elements will be copied into this Map.
          */

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/PrimitiveValueNode.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/util/PrimitiveValueNode.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/OpenWireFormat.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/OpenWireFormat.h Thu May 21 10:26:09 2009
@@ -104,16 +104,20 @@
         /**
          * Allows an external source to add marshalers to this object for
          * types that may be marshaled or unmarhsaled.
          * @param marshaller - the Marshaller to add to the collection.
          */
-        void addMarshaller( marshal::DataStreamMarshaller* marshaller );
+        void addMarshaller( marshal::DataStreamMarshaller* marshaler );
 
         /**
          * Stream based marshaling of a Command, this method blocks until the entire
          * Command has been written out to the output stream.
          *
-         * @param command - The Command to Marshal
-         * @param out - the output stream to write the command to.
+         * @param command
+         *      The Command to Marshal.
+         * @param transport
+         *      The Transport instance that called this method.
+         * @param out
+         *      The output stream to write the command to.
          * @throws IOException
          */
         virtual void marshal( const Pointer<commands::Command>& command,
@@ -123,8 +127,8 @@
 
         /**
          * Stream based un-marshaling, blocks on reads on the input stream until a complete
-         * command has been read and unmarshaled into the correct form.  Returns a Pointer
-         * to the newly unmarshaled Command.
+         * command has been read and un-marshaled into the correct form.  Returns a Pointer
+         * to the newly un-marshaled Command.
          *
          * @param transport - Pointer to the transport that is making this request.
          * @param in - the input stream to read the command from.
@@ -147,7 +151,7 @@
             throw ( decaf::io::IOException );
 
         /**
-         * Utility method that will Tight marshall some internally nested object
+         * Utility method that will Tight marshal some internally nested object
          * that implements the DataStructure interface.  Writes the data to the
          * Data Output Stream provided.
          * @param o - DataStructure object
@@ -164,7 +168,7 @@
          * Utility method used to Unmarshal a Nested DataStructure type object
          * from the given DataInputStream.  The DataStructure instance that is
          * returned is now the property of the caller.
-         * @param ds - DataInputStream to read from
+         * @param dis - DataInputStream to read from
          * @param bs - BooleanStream to read from
          * @returns Newly allocated DataStructure Object
          * @throws IOException if an error occurs.
@@ -175,7 +179,7 @@
 
         /**
          * Utility method to unmarshal an DataStructure object from an
-         * DataInputStream using the Loose Unmarshalling format.  Will read
+         * DataInputStream using the Loose Unmarshaling format.  Will read
          * the Data and construct a new DataStructure based Object, the
          * pointer to the Object returned is now owned by the caller.
          * @param dis - the DataInputStream to read the data from
@@ -183,7 +187,7 @@
          * @throws IOException if an error occurs.
          */
         commands::DataStructure* looseUnmarshalNestedObject(
-            decaf::io::DataInputStream* dis)
+            decaf::io::DataInputStream* dis )
                 throw ( decaf::io::IOException );
 
         /**
@@ -202,7 +206,7 @@
          * Called to re-negotiate the settings for the WireFormatInfo, these
          * determine how the client and broker communicate.
          * @param info - The new Wireformat Info settings
-         * @throws IllegalStateException is the params can't be negotiated.
+         * @throws IllegalStateException is wire format can't be negotiated.
          */
         void renegotiateWireFormat( const commands::WireFormatInfo& info )
             throw ( decaf::lang::exceptions::IllegalStateException );
@@ -232,7 +236,7 @@
 
         /**
          * Sets if the stackTraceEnabled flag is on
-         * @param stackTraceEnabled - ture to turn flag is on
+         * @param stackTraceEnabled - true to turn flag is on
          */
         void setStackTraceEnabled( bool stackTraceEnabled ) {
             this->stackTraceEnabled = stackTraceEnabled;
@@ -248,7 +252,7 @@
 
         /**
          * Sets if the tcpNoDelayEnabled flag is on
-         * @param tcpNoDelayEnabled - ture to turn flag is on
+         * @param tcpNoDelayEnabled - true to turn flag is on
          */
         void setTcpNoDelayEnabled( bool tcpNoDelayEnabled ) {
             this->tcpNoDelayEnabled = tcpNoDelayEnabled;
@@ -278,7 +282,7 @@
 
         /**
          * Sets if the cacheEnabled flag is on
-         * @param cacheEnabled - ture to turn flag is on
+         * @param cacheEnabled - true to turn flag is on
          */
         void setCacheEnabled( bool cacheEnabled ) {
             this->cacheEnabled = cacheEnabled;
@@ -310,7 +314,7 @@
 
         /**
          * Sets if the tightEncodingEnabled flag is on
-         * @param tightEncodingEnabled - ture to turn flag is on
+         * @param tightEncodingEnabled - true to turn flag is on
          */
         void setTightEncodingEnabled( bool tightEncodingEnabled ) {
             this->tightEncodingEnabled = tightEncodingEnabled;
@@ -326,7 +330,7 @@
 
         /**
          * Sets if the sizePrefixDisabled flag is on
-         * @param sizePrefixDisabled - ture to turn flag is on
+         * @param sizePrefixDisabled - true to turn flag is on
          */
         void setSizePrefixDisabled( bool sizePrefixDisabled ) {
             this->sizePrefixDisabled = sizePrefixDisabled;
@@ -104,16 +104,20 @@
          * Allows an external source to add marshalers to this object for
          * types that may be marshaled or unmarhsaled.
-         * @param marshaller - the Marshaller to add to the collection.
+         * @param marshaler - the Marshaler to add to the collection.
          */

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/OpenWireFormatNegotiator.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/activemq/wireformat/openwire/OpenWireFormatNegotiator.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================